@@ -19,16 +19,31 @@ size_of_selfloops <- function(eventlog, type, level, append, ...) {
 #' @export
 
 size_of_selfloops.eventlog <- function(eventlog,
-							  type = c("repeat","redo"),
+							  type = c("all", "repeat","redo"),
 							  level = c("log","case","activity","resource","resource-activity"),
 							  append = FALSE,
 							  ...){
 
+
+	if(all((type) == c("all", "repeat","redo")))
+		message("Using default type: all")
+	if(all((level) == c("log","case","activity","resource","resource-activity")))
+		message("Using default level: log")
+
 	type <- match.arg(type)
 	level <- match.arg(level)
 	level <- deprecated_level(level, ...)
 
-	if(type == "repeat") {
+	if(type == "all") {
+		FUN <- switch(level,
+					  log = all_selfloops_size_log,
+					  case = all_selfloops_size_case,
+					  activity = all_selfloops_size_activity,
+					  resource = all_selfloops_size_resource,
+					  "resource-activity" = all_selfloops_size_resource_activity
+		)
+	}
+	else if(type == "repeat") {
 		FUN <- switch(level,
 					  log = repeat_selfloops_size_log,
 					  case = repeat_selfloops_size_case,
